@@ -43,7 +43,7 @@ class DigiCubeServer:
         self.port = self.config.port
         secret_key = self.config.get("secret", "b3j6casjk7d8szeuwz00hdhuw4ohwDu9o")
         self.db_url = self.config.get("db_url", "sqlite://:memory:")
-        logger.info(f"Using database url %s", self.db_url)
+        logger.info("Using database url %s", self.db_url)
 
         # Inner
         self._inner = _Inner(self)
@@ -284,6 +284,7 @@ class Config:
         # the program.
         logger.info("Reading environment variables. Looking for a .env file.")
         load_dotenv(verbose=True)
+        print(os.environ)
 
         self.default_settings = None
         self.custom_settings = {}
